@@ -16,19 +16,15 @@
 // with Gnome Weather; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
-pkg.initSubmodule('libgd');
 pkg.initGettext();
 pkg.initFormat();
-pkg.require({ 'Gd': '1.0',
-              'Gdk': '3.0',
-              'GdkPixbuf': '2.0',
+pkg.require({ 'Gdk': '3.0',
               'Gio': '2.0',
               'GLib': '2.0',
               'GObject': '2.0',
               'Gtk': '3.0',
               'GWeather': '3.0' });
 
-const Gd = imports.gi.Gd;
 const Gdk = imports.gi.Gdk;
 const Gio = imports.gi.Gio;
 const GLib = imports.gi.GLib;
@@ -64,21 +60,7 @@ const Application = new Lang.Class({
         let location = this.world.deserialize(parameter.deep_unpack());
         let win = this._createWindow();
 
-        let info = this.model.getLocationInfo(location);
-        if (!info) {
-            this.model.addLocation(location, false);
-            info = this.model.getLocationInfo(location);
-        }
-
-        win.showInfo(info);
-    },
-
-    _onNewLocation: function(action, parameter) {
-        let win = this.get_active_window();
-        if (!win)
-            win = this._createWindow();
-
-        win.activate_action('new-location', null);
+        this.model.addNewLocation(location, false);
     },
 
     _initAppMenu: function() {
@@ -91,7 +73,6 @@ const Application = new Lang.Class({
 
     vfunc_startup: function() {
         this.parent();
-        Gd.ensure_types();
 
         Util.loadStyleSheet('/org/gnome/Weather/Application/application.css');
 
@@ -100,7 +81,7 @@ const Application = new Lang.Class({
 
         this.world = GWeather.Location.get_world();
         this.model = new World.WorldModel(this.world, true);
-        this._currentLocationController = new CurrentLocationController.CurrentLocationController(this.model);
+        this.currentLocationController = new CurrentLocationController.CurrentLocationController(this.model);
 
         this.model.connect('notify::loading', Lang.bind(this, function() {
             if (this.model.loading)
@@ -116,11 +97,9 @@ const Application = new Lang.Class({
                             activate: this._onQuit },
                           { name: 'show-location',
                             activate: this._onShowLocation,
-                            parameter_type: new GLib.VariantType('v') },
-                          { name: 'new-location',
-                            activate: this._onNewLocation }]);
+                            parameter_type: new GLib.VariantType('v') }]);
 
-        let gwSettings = new Gio.Settings({ schema: 'org.gnome.GWeather' });
+        let gwSettings = new Gio.Settings({ schema_id: 'org.gnome.GWeather' });
         this.add_action(gwSettings.create_action('temperature-unit'));
 
         this._initAppMenu();
@@ -131,9 +110,10 @@ const Application = new Lang.Class({
 
     _createWindow: function() {
         let win = new Window.MainWindow({ application: this });
+        let notifyId;
 
         if (this.model.loading) {
-            let timeoutId, notifyId;
+            let timeoutId;
             let model = this.model;
 
             timeoutId = GLib.timeout_add(GLib.PRIORITY_DEFAULT, 1000, function() {
@@ -143,6 +123,9 @@ const Application = new Lang.Class({
                 return false;
             });
             notifyId = this.model.connect('notify::loading', function(model) {
+                if (model.loading)
+                    return;
+
                 model.disconnect(notifyId);
                 GLib.source_remove(timeoutId);
                 win.show();
